==> cdi-tck-2.0.7.SP1-dist.zip: org/jboss/cdi/tck/tests/context/conversation/filter/OuterFilter.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.context.conversation.filter;

import java.io.IOException;

import javax.enterprise.context.BusyConversationException;
import javax.inject.Inject;
import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

public class OuterFilter implements Filter {

    @Inject
    Tester tester;

    @Inject
    State state;

    @Override
    public void init(FilterConfig filterConfig) throws ServletException {
    }

    @Override
    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException,
            ServletException {
        tester.testConversationContextIsActive();
        try {
            chain.doFilter(request, response);
        } catch (BusyConversationException e) {
            state.setBusyAttemptMade();
            response.setContentType("text/plain");
            response.getWriter().print("BusyConversationException");
        }
    }

    @Override
    public void destroy() {
    }

}

==> cdi-tck-3.0.2.SP1-dist.zip: org/jboss/cdi/tck/tests/context/conversation/filter/OuterFilter.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.context.conversation.filter;

import java.io.IOException;

import jakarta.enterprise.context.BusyConversationException;
import jakarta.inject.Inject;
import jakarta.servlet.Filter;
import jakarta.servlet.FilterChain;
import jakarta.servlet.FilterConfig;
import jakarta.servlet.ServletException;
import jakarta.servlet.ServletRequest;
import jakarta.servlet.ServletResponse;

public class OuterFilter implements Filter {

    @Inject
    Tester tester;

    @Inject
    State state;

    @Override
    public void init(FilterConfig filterConfig) throws ServletException {
    }

    @Override
    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException,
            ServletException {
        tester.testConversationContextIsActive();
        try {
            chain.doFilter(request, response);
        } catch (BusyConversationException e) {
            state.setBusyAttemptMade();
            response.setContentType("text/plain");
            response.getWriter().print("BusyConversationException");
        }
    }

    @Override
    public void destroy() {
    }

}
